Module: ActionDispatch::Testing::ResponsePredicates
- Defined in:
- lib/action_dispatch/testing/response_predicates.rb
Instance Method Summary collapse
-
#error? ⇒ Boolean
Was there a server-side error?.
-
#missing? ⇒ Boolean
Was the URL not found?.
-
#success? ⇒ Boolean
Was the response successful?.
Instance Method Details
#error? ⇒ Boolean
Was there a server-side error?
26 27 28 29 30 31 32 |
# File 'lib/action_dispatch/testing/response_predicates.rb', line 26 def error? ActiveSupport::Deprecation.warn(" The error? predicate is deprecated and was removed in Rails 6.0.\n Please use server_error? as provided by Rack::Response::Helpers.\n MSG\n server_error?\nend\n") |
#missing? ⇒ Boolean
Was the URL not found?
17 18 19 20 21 22 23 |
# File 'lib/action_dispatch/testing/response_predicates.rb', line 17 def missing? ActiveSupport::Deprecation.warn(" The missing? predicate is deprecated and was removed in Rails 6.0.\n Please use not_found? as provided by Rack::Response::Helpers.\n MSG\n not_found?\nend\n") |
#success? ⇒ Boolean
Was the response successful?
8 9 10 11 12 13 14 |
# File 'lib/action_dispatch/testing/response_predicates.rb', line 8 def success? ActiveSupport::Deprecation.warn(" The success? predicate is deprecated and was removed in Rails 6.0.\n Please use successful? as provided by Rack::Response::Helpers.\n MSG\n successful?\nend\n") |